/// <reference types="codemirror" />
import EventEmitter from 'eventemitter3';
import { Scene } from './types';
export interface MovieOptions {
    /** Delay before starting scene playback */
    beforeDelay: number;
    /** Delay after finishing scene playback */
    afterDelay: number;
}
export declare const enum PlaybackState {
    Idle = "idle",
    Play = "play",
    Pause = "pause"
}
export interface MovieEvents {
    play: [];
    pause: [];
    resume: [];
    stop: [];
    scene: [number];
}
export default class Movie extends EventEmitter<MovieEvents> {
    scenes: Scene[];
    editor: CodeMirror.Editor;
    state: PlaybackState;
    options: MovieOptions;
    private ix;
    private initial;
    private timer;
    constructor(scenes: Scene[], editor: CodeMirror.Editor, opt?: Partial<MovieOptions>);
    /**
     * Play current scenario
     */
    play(): void;
    /**
     * Pause current scenario playback. It can be restored with
     * `play()` method call
     */
    pause(): void;
    /**
     * Stops playback of current scenario
     */
    stop(): void;
    /**
     * Toggle playback of movie scenario
     */
    toggle(): void;
    private requestTimer;
    /**
     * Revers editor to it’s initial state
     */
    private revert;
    /**
     * Prevents user from interacting with editor
     */
    private lock;
    /**
     * Unlocks user interaction with editor
     */
    private unlock;
}
