/// <reference types="codemirror" />
import { Scene, Pos } from './types';
interface SceneTypeOptions {
    /** Delay between character typing, in ms */
    delay: number;
    /** Initial position where to start typing. Default is 'cursor' */
    pos: Pos;
}
interface SceneMoveToOptions {
    /** Delay before actual movement. Use `0` to immediately just to given position */
    delay: number;
    /** Delay after movement, before advancing to next scene */
    afterDelay: number;
}
interface SceneRunOptions {
    /** Delay before each command execution */
    delay: number;
    /** How many times command should be executed */
    times: number;
}
declare type CommandFn = (editor: CodeMirror.Editor, time?: number) => void;
export { default as tooltip } from './widgets/tooltip';
/**
 * Type-in passed text into current editor char-by-char
 */
export declare function type(text: string, opt?: Partial<SceneTypeOptions>): Scene;
/**
 * Wait for a specified timeout, in ms, and moves to next scene
 */
export declare function wait(timeout: number): Scene;
/**
 * Move caret to a specified position
 */
export declare function moveTo(pos: Pos, opt?: Partial<SceneMoveToOptions>): Scene;
/**
 * Shortcut for `moveTo` scene but with immediate cursor position update
 */
export declare function jumpTo(pos: Pos, opt?: Partial<SceneMoveToOptions>): Scene;
export declare function run(command: string | CommandFn, opt?: SceneRunOptions): Scene;
/**
 * Select given range of text
 */
export declare function select(to: Pos, from?: Pos): Scene;
