/// <reference types="codemirror" />
import { Pos, Scene } from '../types';
interface SceneTooltip {
    (text: string | HTMLElement, opt?: Partial<SceneTooltipOptions>): Scene;
    /** Creates new tooltip instance */
    create(text: string, opt?: Partial<SceneTooltipOptions>): HTMLElement;
    /** Displays given tooltip in editor */
    show(tooltip: HTMLElement, opt?: Partial<SceneTooltipOptions>): void;
    /** Hides given tooltip in editor */
    hide(tooltip: HTMLElement, opt?: Partial<SceneTooltipOptions>): void;
}
export interface SceneTooltipOptions {
    /** Time to wait before hiding tooltip, ms */
    wait: number;
    /** Position where tooltip should point to */
    pos: Pos;
    /** Horizontal alignment of tooltip relative to cursor location */
    alignX?: 'left' | 'center' | 'right';
    /** Vertical alignment of tooltip relative to cursor location*/
    alignY?: 'above' | 'below';
    /** Case class name for building tooltip UI */
    baseClass: string;
    /** CSS animation value for displaying tooltip */
    animationShow?: string;
    /** CSS animation value for hiding tooltip */
    animationHide?: string;
    /**
     * Method for attaching tooltip to editor: should mount element into DOM.
     * If not specified, a default `editor.addWidget()` is used.
     */
    attach?: (editor: CodeMirror.Editor, tooltip: HTMLElement, pos: CodeMirror.Position, options: SceneTooltipOptions) => void;
}
declare const tooltipWidget: SceneTooltip;
export default tooltipWidget;
